require 'spec_helper'

module Dockerploy
  describe CLI do
    let(:fixture_path) { 'spec/fixtures/config.yml' }
    before do
      stub_const('Dockerploy::Configuration::DEFAULT_CONFIG_FILE', fixture_path)
    end

    describe '#init' do
      include FakeFS::SpecHelpers
      it 'runs docker ps in servers' do
        FakeFS do
          expect(Template).to receive(:generate).and_return('template')
          cli = described_class.new
          cli.init
          expect(File.read('docker/config.yml.sample')).to eq('template')
        end
      end
    end

    describe '#ps' do
      it 'runs docker ps in servers' do
        expect_any_instance_of(SSHClient).to receive(:command).with('docker ps | grep app')
        cli = described_class.new
        cli.ps('test')
      end
    end

    describe '#build' do
      it 'runs docker build' do
        expected_command = 'env DOCKER_HOST=tcp://test.host:4243 docker build -t docker/image .'
        expect_any_instance_of(ShellClient).to receive(:command).with(expected_command)
        cli = described_class.new
        cli.build
      end

      context 'with tag' do
        it 'runs docker build with tag name' do
          expected_command = 'env DOCKER_HOST=tcp://test.host:4243 docker build -t docker/image:tag .'
          expect_any_instance_of(ShellClient).to receive(:command).with(expected_command)
          cli = described_class.new([], tag: 'tag')
          cli.build
        end
      end
    end

    describe '#push' do
      it 'pushes the image' do
        expected_command = 'env DOCKER_HOST=tcp://test.host:4243 docker push docker/image'
        expect_any_instance_of(ShellClient).to receive(:command).with(expected_command)
        cli = described_class.new
        cli.push
      end

      context 'with tag' do
        it 'pushes the image with tag name' do
          expected_command = 'env DOCKER_HOST=tcp://test.host:4243 docker push docker/image:tag'
          expect_any_instance_of(ShellClient).to receive(:command).with(expected_command)
          cli = described_class.new([], tag: 'tag')
          cli.push
        end
      end
    end

    describe '#pull' do
      it 'pulls the image' do
        expect_any_instance_of(SSHClient).to receive(:command).with('docker pull docker/image')
        cli = described_class.new
        cli.pull('test')
      end

      context 'with tag' do
        it 'pulls the image with tag name' do
          expected_command = 'docker pull docker/image:tag'
          expect_any_instance_of(SSHClient).to receive(:command).with(expected_command)
          cli = described_class.new([], tag: 'tag')
          cli.pull('test')
        end
      end
    end

    describe '#deploy' do
      it 'creates a container on server' do
        expect_any_instance_of(SSHClient).to receive(:command).with('docker rm -f app_8080')
        expected_command = <<-SHELL
docker run -d --name app_8080 --hostname app -p container.host:1022:22 -p container.host:8080:80   docker/image
SHELL
        expected_command.chomp!
        expect_any_instance_of(SSHClient).to receive(:command).with(expected_command)
        cli = described_class.new
        cli.deploy('test')
      end

      context 'with tag' do
        it 'creates a container on server' do
          expect_any_instance_of(SSHClient).to receive(:command).with('docker rm -f app_8080')
          expected_command = <<-SHELL
docker run -d --name app_8080 --hostname app -p container.host:1022:22 -p container.host:8080:80   docker/image:tag
          SHELL
          expected_command.chomp!
          expect_any_instance_of(SSHClient).to receive(:command).with(expected_command)
          cli = described_class.new([], tag: 'tag')
          cli.deploy('test')
        end
      end
    end
  end
end
