require 'spec_helper'

module Dockerploy
  describe Image do
    let(:fixture_path) { 'spec/fixtures/config.yml' }
    before do
      stub_const('Dockerploy::Configuration::DEFAULT_CONFIG_FILE', fixture_path)
    end

    let(:config) { Configuration.new(env: 'test') }
    let(:options) { {} }

    describe '#build' do
      subject { Image.new(config, options).build }

      it 'runs docker build' do
        expected_command = 'env DOCKER_HOST=tcp://test.host:4243 docker build -t docker/image .'
        expect_any_instance_of(ShellClient).to receive(:command).with(expected_command)
        subject
      end

      context 'with tag' do
        let(:options) { { tag: 'tag' } }

        it 'runs docker build with tag' do
          expected_command = 'env DOCKER_HOST=tcp://test.host:4243 docker build -t docker/image:tag .'
          expect_any_instance_of(ShellClient).to receive(:command).with(expected_command)
          subject
        end
      end
    end

    describe '#push' do
      subject { Image.new(config, options).push }

      it 'runs docker push' do
        expected_command = 'env DOCKER_HOST=tcp://test.host:4243 docker push docker/image'
        expect_any_instance_of(ShellClient).to receive(:command).with(expected_command)
        subject
      end

      context 'with tag' do
        let(:options) { { tag: 'tag' } }

        it 'runs docker push with tag name' do
          expected_command = 'env DOCKER_HOST=tcp://test.host:4243 docker push docker/image:tag'
          expect_any_instance_of(ShellClient).to receive(:command).with(expected_command)
          subject
        end
      end
    end

    describe '#pull' do
      subject { Image.new(config, options).pull }

      it 'pulls the image' do
        expected_command = 'docker pull docker/image'
        expect_any_instance_of(SSHClient).to receive(:command).with(expected_command)
        subject
      end

      context 'with tag' do
        let(:options) { { tag: 'tag' } }

        it 'runs docker pull with tag name' do
          expected_command = 'docker pull docker/image:tag'
          expect_any_instance_of(SSHClient).to receive(:command).with(expected_command)
          subject
        end
      end
    end
  end
end
