require 'spec_helper'

module Dockerploy
  describe Template do
    describe '.application_name' do
      subject { described_class.application_name }
      it 'returns application name from current working directory' do
        expect(Dir).to receive(:getwd).and_return('/home/sunjin')
        expect(subject).to eq('sunjin')
      end
    end

    describe '.project_name' do
      subject { described_class.project_name }

      it 'returns project name from git repository name' do
        client = double(output: 'git@github.com:org/project-name.git')
        expect(ShellClient).to receive(:new).and_return(client)
        expect(client).to receive(:command).with('git config --get remote.origin.url')
        expect(subject).to eq('org/project-name')
      end
    end

    describe '.generate' do
      subject { described_class.generate }

      before do
        allow(Dir).to receive(:getwd).and_return('/home/application-name')
        client = double(output: 'git@github.com:org/project-name.git')
        allow(ShellClient).to receive(:new).and_return(client)
        allow(client).to receive(:command).with('git config --get remote.origin.url')
        ENV['USER'] = 'sunjin'
      end

      it 'generates template file' do
         result = <<-YML
image_name: org/project-name
docker_username: sunjin
docker_host: tcp://:2375
application_name: application-name
development:
  branch: master
  tagging: true
  volumes: []
  servers:
    - host: 0.0.0.0
      username: sunjin
      password:
      port: 22
      container:
        host: 0.0.0.0
        ssh_port: 22
        http_port: 80
YML

        expect(subject).to eq(result.chop)
      end
    end
  end
end
